==> apache-camel-3.10.0-src.zip: apache-camel-3.10.0/components/camel-saxon/src/test/java/org/apache/camel/component/xquery/XQueryNullHeaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractXmlApplicationContext;

public class XQueryNullHeaderTest extends CamelSpringTestSupport {

    @Test
    public void testHeader() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<employee id=\"James\"><name><firstName>James</firstName>"
                                    + "<lastName>Strachan</lastName></name><location><city>London</city></location></employee>");

        template.sendBodyAndHeader("direct:start", "<person user='James'><firstName>James</firstName>"
                                                   + "<lastName>Strachan</lastName><city>London</city></person>",
                "foo", "123");

        assertMockEndpointsSatisfied();
    }

    @Test
    public void testHeaderWithNull() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<employee id=\"James\"><name><firstName>James</firstName>"
                                    + "<lastName>Strachan</lastName></name><location><city>London</city></location></employee>");

        template.sendBodyAndHeader("direct:start", "<person user='James'><firstName>James</firstName>"
                                                   + "<lastName>Strachan</lastName><city>London</city></person>",
                "foo", null);

        assertMockEndpointsSatisfied();
    }

    @Override
    protected AbstractXmlApplicationContext createApplicationContext() {
        return newAppContext("xqueryExampleTest.xml");
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-saxon/src/test/java/org/apache/camel/component/xquery/XQueryNullHeaderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractXmlApplicationContext;

public class XQueryNullHeaderTest extends CamelSpringTestSupport {

    @Test
    public void testHeader() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<employee id=\"James\"><name><firstName>James</firstName>"
                                    + "<lastName>Strachan</lastName></name><location><city>London</city></location></employee>");

        template.sendBodyAndHeader("direct:start", "<person user='James'><firstName>James</firstName>"
                                                   + "<lastName>Strachan</lastName><city>London</city></person>",
                "foo", "123");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Test
    public void testHeaderWithNull() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:result");
        mock.expectedBodiesReceived("<employee id=\"James\"><name><firstName>James</firstName>"
                                    + "<lastName>Strachan</lastName></name><location><city>London</city></location></employee>");

        template.sendBodyAndHeader("direct:start", "<person user='James'><firstName>James</firstName>"
                                                   + "<lastName>Strachan</lastName><city>London</city></person>",
                "foo", null);

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected AbstractXmlApplicationContext createApplicationContext() {
        return newAppContext("xqueryExampleTest.xml");
    }
}
